@@ -5,6 +5,8 @@
 */
 
 #include "editorpage.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "KSplitterCollapserButton"
 #include "contactprintthemeeditorutil.h"
 #include "contactprintthemepreview.h"
@@ -48,7 +50,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 
     if (mType == MainPage) {
         ContactPrintThemeEditorutil contactUtil;
-        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("Global"));
+        KConfigGroup group(KSharedConfig::openConfig(), u"Global"_s);
         mEditor->setPlainText(group.readEntry("defaultTemplate", contactUtil.defaultTemplate()));
     }
     mMainSplitter->addWidget(mEditor);
@@ -61,7 +63,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
     connect(mEditor->editor(), &QPlainTextEdit::textChanged, this, &GrantleeThemeEditor::EditorPage::changed);
 
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
+        KConfigGroup group(KSharedConfig::openConfig(), u"EditorPage"_s);
         const QList<int> size{400, 100};
         mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
         mWidgetSplitter->setSizes(group.readEntry("widgetSplitter", size));
@@ -71,7 +73,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 EditorPage::~EditorPage()
 {
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
+        KConfigGroup group(KSharedConfig::openConfig(), u"EditorPage"_s);
         group.writeEntry("mainSplitter", mMainSplitter->sizes());
         group.writeEntry("widgetSplitter", mWidgetSplitter->sizes());
     }
